@@ -30,10 +30,10 @@
  DAMAGE. 
  =========================================================================*/
 
-/**	@file
+/*
  *	command functions
  *
- *	@NAME{gtags-cscope} - interactive C symbol or text cross-reference (@NAME{cscope})
+ *	gtags-cscope - interactive C symbol or text cross-reference (cscope)
  */
 
 #include "global-cscope.h"
@@ -50,9 +50,6 @@
 #endif
 #include <ctype.h>
 
-static char const rcsid[] = "$Id: command.c,v 1.10 2014/03/17 06:46:06 shigio Exp $";
-
-
 int	selecting;
 unsigned int   curdispline = 0;
 
