@@ -1,5 +1,5 @@
-/* ANSI-C code produced by gperf version 3.0.3 */
-/* Command-line: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/gperf --language=ANSI-C --struct-type --slot-name=name --hash-fn-name=php_hash --lookup-fn-name=php_lookup  */
+/* ANSI-C code produced by gperf version 3.0.4 */
+/* Command-line: gperf --language=ANSI-C --struct-type --slot-name=name --hash-fn-name=php_hash --lookup-fn-name=php_lookup  */
 /* Computed positions: -k'1-2,4-6,9' */
 
 #if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
@@ -126,12 +126,10 @@ struct keyword { char *name; int token; };
 #define MAX_HASH_VALUE 602
 /* maximum key range = 601, duplicates = 0 */
 
-#ifdef __GNUC__
-__inline
-#else
-#ifdef __cplusplus
+#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L) || defined(__cplusplus) || defined(__GNUC_STDC_INLINE__)
 inline
-#endif
+#elif defined(__GNUC__)
+__inline
 #endif
 static unsigned int
 php_hash (register const char *str, register unsigned int len)
@@ -165,7 +163,7 @@ php_hash (register const char *str, register unsigned int len)
       603, 603, 603, 603, 603, 603, 603, 603, 603, 603,
       603, 603, 603, 603, 603, 603
     };
-  register unsigned int hval = len;
+  register int hval = len;
 
   switch (hval)
     {
@@ -194,6 +192,12 @@ php_hash (register const char *str, register unsigned int len)
   return hval;
 }
 
+#ifdef __GNUC__
+__inline
+#if defined __GNUC_STDC_INLINE__ || defined __GNUC_GNU_INLINE__
+__attribute__ ((__gnu_inline__))
+#endif
+#endif
 struct keyword *
 php_lookup (register const char *str, register unsigned int len)
 {
@@ -519,9 +523,9 @@ php_lookup (register const char *str, register unsigned int len)
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
     {
-      unsigned int key = php_hash (str, len);
+      register int key = php_hash (str, len);
 
-      if (key <= MAX_HASH_VALUE)
+      if (key <= MAX_HASH_VALUE && key >= 0)
         {
           register const char *s = wordlist[key].name;
 
